# Title:	MT-LJPost
# Summary:	A plugin for posting to livejournal whenever you post/edit an entry to MOveable Type
# Author:	Gavin Mogan (halkeye@halkeye.net) (http://www.halkeye.net/)
# Version:	1.0.5
# Date:		Febuary 09, 2004
# See .pl file for version information

package MT::Plugins::MTLJPost;
use lib '../../../lib';

use strict;

use MT::App;
use MT::ConfigMgr;
use MT::Blog;
use MT::PluginData;

use Digest::MD5 qw(md5_hex);

use vars qw( $VERSION );
my $VERSION = "1.0.5";

@MT::Plugins::MTLJPost::ISA = qw( MT::App );

#----------------------------------------------------------------------------
# 
#   Name: init
#
#   Overview:
#	Sets up MT::App keys.
#
#   Calling Sequence ( and options )
#	N/A
#
#   Returns: MT::App object
#
#----------------------------------------------------------------------------

sub init {
	my $app = shift;
	$app->SUPER::init(@_) or return;
	$app->add_methods (
		'list'	=> \&lj_post_show,
		'mtljpost_test' => \&lj_post_cfg,
		'mtljpost_cfg' => \&lj_post_cfg,
		'list_blogs' => \&list_blogs,
		);
	$app->{default_mode} = 'list';
	$app->{template_dir} = 'cms';
	$app->{requires_login} = 1;
	$app->{user_class} = "MT::Author";

  	$app;
}

sub lj_post_show {
	my $app = shift;
	$app->lj_post_cfg();	
}

sub lj_post_cfg {
	my $app = shift;
	my $blog = undef;
	my %param;
	if ( defined $app->{query}->param('blog_id') ) {
		$blog = MT::Blog->load($app->{query}->param('blog_id')+0) || undef;
	}
	
	$param{'mtljpost_version'} = $VERSION;
	if (defined $blog) {
		#return $app->build_page ('error.tmpl', { error => "No Such Blog." . (defined $app->errstr ? " " . $app->errstr : "") });
		
		my $data = MT::PluginData->load({ plugin => 'MTLJPost',
		                                  key    => $blog->id }) || undef;
		
		my $logindata;
			
		if (defined $data) {
			#%logindata = ${$data->data};
			$logindata = $data->data;
			#use Data::Dumper; die Dumper($$logindata{'site'}, $logindata, $data->data);
		}
			
		$param{'blog_id'} = $blog->id;
		$param{'site'} = $app->{query}->param('site') || $$logindata{'site'} || 'www.livejournal.com';
		$param{'username'} = $app->{query}->param('username') || $$logindata{'username'} || 'test';
		$param{'password'} = $app->{query}->param('password') || $$logindata{'pass'} || 'test';
		$param{'enabled'} = $app->{query}->param('enabled') || $$logindata{'enabled'} || 0;
		
		if (defined $app->{query}->param('__type'))
		{
			if ($app->{query}->param('__type') eq "mtljpost_test")
			{
				my $lj = new LJ::Simple ({
					user 	=> $param{'username'},
					pass	=> $param{'password'},
					site	=> $param{'site'},
				});
			
				$param{'errmsg'} = $LJ::Simple::error unless (defined $lj);
				if (defined $lj )
				{
					my $message = $lj->message() || "Success";
					$message =~ s/(http|ftp|https|telnet):\/\/(\S+)/<a href=\"$1\:\/\/$2\">$2<\/a>/g;
					#$message =~ s/http:\/\/(\S+)/<a href=\"http://$1\">$1<\/a>/g;
					#use Data::Dumper; die Dumper($message, $lj->message());
					$param{'loginmsg'} = $message;
				}
			}
			unless (defined $data) {
				$data = MT::PluginData->new;
			}
			$$logindata{'enabled'} = $param{'enabled'};
			$$logindata{'username'} = $param{'username'};
			$$logindata{'pass'} = $param{'password'};
			$$logindata{'site'} = $param{'site'};
			$data->plugin('MTLJPost');
			$data->key($blog->id);
			$data->data($logindata);
			$data->save or ($param{'errmsg'} .= $data->errstr);
		}
	}
	else
	{
		require MT::Blog;
		require MT::Permission;
		require MT::Entry;
		require MT::Comment;
		my $author = $app->{author};
		my @perms = MT::Permission->load({ author_id => $author->id });
		my %perms = map { $_->blog_id => $_ } @perms;
		my @blogs = MT::Blog->load;
		my @data;
		my $i = 1;
		for my $blog (@blogs) {
		   	my $blog_id = $blog->id;
		   	my $perms = $perms{ $blog_id };
		   	next unless $perms->can_edit_config;
		        my $row = { id => $blog->id, name => uc($blog->name),
                	    description => $blog->description };
        		$row->{is_odd} = $i++ % 2 ? 1 : 0;
        		push @data, $row;
    		}
		$param{blog_loop} = \@data;
#		use Data::Dumper; 
#		die Dumper(@data);
	}
	$app->build_page ('MTLJPost.tmpl', \%param);
	# $app->redirect ($app->uri . "?__mode=gavin")
}
sub check_pm {
  my $app = shift;

}  

sub list_blogs {
    my $app = shift;
    my $q = $app->{query};
    require MT::Blog;
    require MT::Permission;
    require MT::Entry;
    require MT::Comment;
    my $author = $app->{author};
    my @perms = MT::Permission->load({ author_id => $author->id });
    my %perms = map { $_->blog_id => $_ } @perms;
    my @blogs = MT::Blog->load;
    my @data;
    my %param;
    my $i = 1;
    for my $blog (@blogs) {
        my $blog_id = $blog->id;
        my $perms = $perms{ $blog_id };
        next unless $perms && $perms->role_mask;
        next unless $perms->can_edit_config;
        my $row = { id => $blog->id, name => uc($blog->name),
                    description => $blog->description };
        $row->{is_odd} = $i++ % 2 ? 1 : 0;
        push @data, $row;
    }
    $param{blog_loop} = \@data;
    $param{can_create_blog} = $author->can_create_blog;
    $param{can_view_log} = $author->can_view_log;
    $param{saved_deleted} = $q->param('saved_deleted');
    $app->build_page('list_blog.tmpl', \%param);
}


sub get_login($)
{
	my $blog_id = shift;
	my $data = MT::PluginData->load({ plugin => 'MTLJPost', 
					  key    => $blog_id }) || undef;
					  
 	return undef unless defined $data;
 	my $logindata = $data->data;
 	my %login = ();
 	return undef if ($$logindata{'enabled'} eq 0);
 	$login{'site'} = $$logindata{'site'} || 'www.livejournal.com';
	$login{'user'} = $$logindata{'username'} || 'test';
	$login{'pass'} = $$logindata{'pass'} || 'test';
	$login{'enabled'} = $$logindata{'enabled'} || 0;
	# This blog post
	return \%login;
	

}


1;
