# Title:	MT-LJPost
# Summary:	A plugin for posting to livejournal whenever you post/edit an entry to MOveable Type
# Author:	Gavin Mogan (halkeye@halkeye.net) (http://www.halkeye.net/)
# Version:	1.0.5
# Date:		Febuary 09, 2004
#
# History
# 1.0.0 - January 29, 2004
#  - Inital Release
# 1.0.1 - January 30, 2004
#  - Removing needing so many variables
#  - Adding selecting of which blog you want.
#
# 1.0.2 - January 30, 2004
#  - Added config file because I got tired of always having to change the file for release
#      this file goes into your mt directory, not plugins (for now, i'll fix it next version or something)
#  # Format: blogid site username password
#  #         3 www.livejournal.com test test
#  #         4 www.deadjournal.com:90 test test
#  - Added handler to check for LJ::Simple and give a message without it
#
# 1.0.3 - January 30, 2004
#  - Entries will now edit after the inital post.
#  - If an entry doesn't save to livejournal, just hit save again
#  - Added support for exerpts / lj-cut
#  - Date of LJ post is date of Actual Entry. You'll have to watch out for backdated entries
#      If its a problem, set the date to now, post, then reset to old.
#      Temp Fix
#  - Convert Line Breaks actually working.
#
# 1.0.4 - January 30, 2004
#  - Date fix, oooopsies
#
# 1.0.5 - Febuary 09, 2004
#  - Started some hooks for MT Plugin Manager
#  - Cleaned up some error messages
#  - Disabled comments
#  - Deletes from livejournal when entry is deleted from MT
#  - Web interface to do configuration /mt-ljpost.cgi
#
# Information about this plugin can be found at
# http://www.halkeye.net/archives/000073.html (perm link later)
#
# Requires the LJ::Simple perl module - http://www.bpfh.net/computing/software/LJ%3a%3aSimple/
# Or CPAN as i prefer.
#
# Copyright 2004 Gavin Mogan
# This code cannot be redistributed without
# permission from the author. 

use lib '../lib';
use lib '../extlib';

use warnings;
use strict;
package MT::Plugins::MTLJPost;
use MT::Plugins::MTLJPost;
use MT::Entry;
use MT::Blog;
use MT::PluginData;
use MT;



my $VERSION = '1.0.5';
my $mt_entry_save_handler;
my $mt_entry_remove_handler;

=cut
my $blog_id;

eval "use MT::Plugins::Config;";
unless (defined $@) {
	require MT::Blog;
	require MT::Author;
	MT::Plugins::Config->add_variable ( Blog_ID => {
		plugin          => 'MTLJPost',
		var             => \$blog_id,
		desc            => "Blogs that will post to livejournal",
		allowed_values  => { map { $_->name => $_->id } MT::Blog->load },
		use_hash_values => 1,
	});
	# Livejournal Server
	# Livejournal username
	# Livejournal password
}
=cut

{
	# Trap ugly redefinition warnings
	local $SIG{__WARN__} = sub {  }; 

	# Replace MT::Entry::save with our 
	# own subroutine entrySave() but save
	# the code in $mt_entry_save_handler.
	#
	$mt_entry_save_handler = \&MT::Entry::save;
	*MT::Entry::save = \&entrySave; 
	# Same with MT::entry:remove
	$mt_entry_remove_handler = \&MT::Entry::remove;
	*MT::Entry::remove = \&removeEntry; 
}  

sub removeEntry {
	my $entry = shift;
	my $logindata = get_login($entry->blog_id);
	return &$mt_entry_save_handler($entry) unless (defined $logindata);
	my $lj = new LJ::Simple ({
		user 	=> $$logindata{'user'},
		pass	=> $$logindata{'pass'},
		site	=> $$logindata{'site'},
	});
	
	if (!(defined $lj)) {
		return $entry->error("Failed to log into LiveJournal:" . $LJ::Simple::error);
	}

	my $err = &$mt_entry_remove_handler($entry);
	return $err unless ($err);

	my $blog = MT::Blog->load($entry->blog_id);
	my $data = MT::PluginData->load({ plugin => 'MTLJPost',
	                                  key    => $entry->blog_id . "_" . $entry->id }) || undef;

	if (defined $data)
	{
		my $itemid = $data->data;
		$itemid = $$itemid;
		(defined $lj->DeleteEntry($itemid)) || return $entry->error("Failed to get Delete Entry: " . $LJ::Simple::error . "\n");
		$data->remove();
	}

}

sub entrySave {
	my $entry = shift;
	my $logindata = get_login($entry->blog_id);
	return &$mt_entry_save_handler($entry) unless (defined $logindata);
	my $lj = new LJ::Simple ({
		user 	=> $$logindata{'user'},
		pass	=> $$logindata{'pass'},
		site	=> $$logindata{'site'},
	});
	
	if (!(defined $lj)) {
		return $entry->error("Failed to log into LiveJournal:" . $LJ::Simple::error);
	}

	my $err = &$mt_entry_save_handler($entry);
	return $err unless ($err);
	
	eval {require LJ::Simple};
	die "Need LJ::Simple" if $@;
	eval {require POSIX};
	die "Need POSIX" if $@;

	use LJ::Simple;
	use POSIX qw(mktime difftime);

	# disable to debug
	
	my $blog = MT::Blog->load($entry->blog_id);
	my $data = MT::PluginData->load({ plugin => 'MTLJPost',
	                                  key    => $entry->blog_id . "_" . $entry->id }) || undef;
	# Build up the subject
	my $subject = $blog->name . ": " . $entry->title;
			
	my $body = MT->apply_text_filters($entry->text, $entry->text_filters);
		
	if ( defined $entry->text_more && $entry->text_more ne "") { # $entry->text_more =~ /^\s*$/s ) {
		$body .= "<lj-cut>\n";
		$body .= MT->apply_text_filters($entry->text_more, $entry->text_filters);
		$body .= "</lj-cut>";
	}
	$body .= "<br />";
	$body .= "[<a href=\"" . $blog->site_url . "\">" . $blog->name . "</a>] (<a href=\"" . $entry->permalink . "\">Permanent link to this entry</a>)<br />";
	my $date = $entry->created_on;
	$date =~ /(\d{4})(\d{2})(\d{2})(\d{2})(\d{2})(\d{2})/;
	my $time_t = mktime($6, $5, $4, $3, $2-1, $1-1900) || die "error";

	my $event=();
	
	# yes this is code duplication
	if (defined $data)
	{
		my %Entries=();
		my $itemid = $data->data;
		$itemid = $$itemid;
		(defined $lj->GetEntries(\%Entries, undef, "one", $itemid )) || $entry->error("Failed to get Previous Entry: " . $LJ::Simple::error . "\n");
		$event = (values %Entries)[0];
	}
	else
	{
		my %Event=();
		$lj->NewEntry(\%Event) || $entry->error("Failed to create new entry: " . $LJ::Simple::error . "\n");
		$event = \%Event;
		$lj->Setprop_backdate(\%Event, 1);
		# 3600 Seconds gives you an hour window to post it properly, otherwise it gets marked as back dated and you have to manually fix it.
		$lj->Setprop_backdate(\%Event, 0) if (difftime(time(), $time_t) < 3600);
	}
	$lj->SetEntry($event,$body) || $entry->error("Failed to set entry: " . $LJ::Simple::error . "\n");
	$lj->SetSubject($event,$subject) || $entry->error("Failed to set subject: " . $LJ::Simple::error . "\n");
	$lj->Setprop_nocomments($event,1);
	$lj->Setprop_preformatted($event, 1) if ($entry->convert_breaks);
	$lj->Setprop_preformatted($event, 0) unless ($entry->convert_breaks);
	$lj->SetDate($event,$time_t) || $entry->error("Failed to set date: " . $LJ::Simple::error . "\n");	
	if (!(defined $data)) {
		$data = MT::PluginData->new;
		$data->plugin('MTLJPost');
		$data->key($entry->blog_id . "_" . $entry->id);

		my ($item_id,$anum,$html_id)=$lj->PostEntry($event);
		(defined $item_id) || $entry->error("$0: Failed to post journal entry: " . $LJ::Simple::error . "\n");
		$data->data(\$item_id);
		$data->save or die $data->errstr;
	} 
	else
	{
		$lj->EditEntry($event) || $entry->error("$0: Failed to edit entry: " . $LJ::Simple::error . "\n");
	}
  
} 

=cut

      Given a context $ctx (an MT::Template::Context object) and an optional
       set of conditions \%cond, builds a template into its output form. The
       template is first parsed into a list of tokens, then is inter-
       preted/executed to generate the final output.

       If specified, \%cond should be a reference to a hash with MT tag names
       (without the leading "MT") as the keys, and boolean flags as the val-
       ues--the flags specify whether the template interpreter should include
       any conditional containers found in the template body.


BEGIN {

	use MT::Template;
	my $tmpl = MT::Template->load($tmpl_id);
        unless (defined($tmpl))
        {
           $tmpl->name('MTLJPost Template');
           $tmpl->type('custom');
           $tmpl->save or die $tmpl->errstr;
        }
};
=cut

1;
